from profile_python.networking import Networking
from profile_python.endpoint import Endpoint
from rich.console import Console
from rich.table import Table
import pyfiglet

if __name__ == "__main__":

    console = Console()

    ascii_banner = pyfiglet.figlet_format("Profile GitHub")
    print(ascii_banner)

    console.print("🏠 Welcome, write your GitHub user to see their profile and repositories 🔥", style="#FFFF00")
    user = input("Enter your username: ")

    url_data = Endpoint().data(user)
    url_repo = Endpoint().repo(user)

    networking = Networking()
    response_datas = networking.request(url_data)
    response_repos = networking.request(url_repo)

    values_datas = networking.parsing(response_datas)
    values_repos = networking.parsing(response_repos)


    def get_datas(datas):
        print(datas['login'])
        print(datas['name'])
        print(datas['bio'])
        print(datas['company'])
        print(datas['blog'])
        print(datas['location'])


    def get_repos(repos):
        for repo in repos:
            table = Table(show_header=True, header_style="bold magenta")
            table.add_column("Name Repository", style="bold red")
            table.add_column("Language")
            table.add_column("Forks")
            table.add_column("Stars")

            table.add_row(
                repo['name'],
                repo['language'],
                str(repo['forks_count']),
                str(repo['stargazers_count'])
            )

            console.print(table)

    print("-----------------------------------------------")

    print("1 - My datas")
    print("2 - Repositories")

    print("-----------------------------------------------")

    option = input("Choose an option: ")

    if option == "1":
        get_datas(values_datas)
    elif option == "2":
        get_repos(values_repos)
    else:
        print("This option does not exist")



path = "https://api.github.com/users/"

class Endpoint(object):

    def data(self, user):
        url = path + str(user)
        return url

    def repo(self, user):
        url = path + str(user) + "/repos"
        return url



import unittest
from profile_python.networking import Networking

class TestNetworking(unittest.TestCase):

    def test_request_success(self):
        json = '["animal","career","celebrity","dev","explicit","fashion","food","history",' \
               '"money","movie","music","political","religion","science","sport","travel"]'

        url = "https://api.chucknorris.io/jokes/categories"
        networking = Networking()
        response = networking.request(url)
        assert response == json

    def test_parsing_success(self):
        url = "https://api.chucknorris.io/jokes/categories"
        networking = Networking()
        response = networking.request(url)

        value = networking.parsing(response)
        assert value[0] == "animal"

if __name__ == '__main__':
    unittest.main()



import unittest
from profile_python.endpoint import Endpoint

class TestEndpoint(unittest.TestCase):

    def test_get_url_data_with_success(self):
        endpoint = Endpoint().data("user")
        assert endpoint == "https://api.github.com/users/user"

    def test_get_url_repo_with_success(self):
        endpoint = Endpoint().repo("user")
        assert endpoint == "https://api.github.com/users/user/repos"

if __name__ == '__main__':
    unittest.main()



import setuptools

with open("README.md", "r") as fh:
    long_description = fh.read()

setuptools.setup(
    name="profile-python",
    version="0.0.4",
    author="João Lucas",
    author_email="joaolucasfp2001@gmail.com",
    description="Profile python is a script for you to view your data and github repositories.",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/heroesofcode/profile-python",
    packages=setuptools.find_packages(),
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    install_requires=[
        'rich',
        'requests',
        'pyfiglet'
    ],
    project_urls={
        'Homepage': 'https://github.com/heroesofcode/profile-python',
    },
    entry_points={
        'console_scripts': [
            'profile-python=profile_python.__main__:main',
        ],
    },
)



import requests
import json

class Networking(object):

    def request(self, url):
        try:
            response = requests.get(url)

            if response.status_code == 200:
                return response.text
        except:
            print("Error making request")

    def parsing(self, value):
        try:
            return json.loads(value)
        except:
            print("Error making parsing")